@@ -7,7 +7,6 @@ use crate::vec2::Vec2;
 use kurbo::TranslateScale as KTranslateScale;
 use pyo3::prelude::*;
 use pyo3::types::PyType;
-use pyo3::PyNumberProtocol;
 
 #[pyclass(subclass)]
 #[derive(Clone, Debug)]
@@ -112,26 +111,25 @@ impl TranslateScale {
         let p: Rect = (self.0 * rhs.0).into();
         Ok(p)
     }
-}
 
-#[pyproto]
-impl PyNumberProtocol<'_> for TranslateScale {
-    fn __mul__(lhs: Self, rhs: &PyAny) -> PyResult<PyObject> {
+    fn __mul__(slf: PyRef<'_, Self>, rhs: &PyAny) -> PyResult<PyObject> {
         Python::with_gil(|py| {
             let magic = PyModule::import(py, "kurbopy.magic")?;
-            magic.getattr("magic_mul")?.call1((lhs, rhs))?.extract()
+            magic.getattr("magic_mul")?.call1((slf, rhs))?.extract()
         })
     }
-    fn __add__(lhs: Self, rhs: &PyAny) -> PyResult<PyObject> {
+
+    fn __add__(slf: PyRef<'_, Self>, rhs: &PyAny) -> PyResult<PyObject> {
         Python::with_gil(|py| {
             let magic = PyModule::import(py, "kurbopy.magic")?;
-            magic.getattr("magic_add")?.call1((lhs, rhs))?.extract()
+            magic.getattr("magic_add")?.call1((slf, rhs))?.extract()
         })
     }
-    fn __sub__(lhs: Self, rhs: &PyAny) -> PyResult<PyObject> {
+
+    fn __sub__(slf: PyRef<'_, Self>, rhs: &PyAny) -> PyResult<PyObject> {
         Python::with_gil(|py| {
             let magic = PyModule::import(py, "kurbopy.magic")?;
-            magic.getattr("magic_sub")?.call1((lhs, rhs))?.extract()
+            magic.getattr("magic_sub")?.call1((slf, rhs))?.extract()
         })
     }
 }
